@@ -1,10 +1,13 @@
-package Hook::Modular::Cache;
-use warnings;
+use 5.008;
 use strict;
+use warnings;
+
+package Hook::Modular::Cache;
+our $VERSION = '1.100820';
+# ABSTRACT: Cache for Hook::Modular
 use File::Path;
 use File::Spec;
 use UNIVERSAL::require;
-our $VERSION = '0.09';
 
 sub new {
     my ($class, $conf, $name) = @_;
@@ -88,49 +91,79 @@ sub DESTROY {
     $self->{cache}->purge if $self->{to_purge};
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 Hook::Modular::Cache - Cache for Hook::Modular
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    Hook::Modular::Cache->new;
+version 1.100820
 
-=head1 DESCRIPTION
+=head1 METHODS
 
-None yet.
+=head2 get
+
+FIXME
+
+=head2 get_callback
+
+FIXME
+
+=head2 new
+
+FIXME
+
+=head2 path_to
+
+FIXME
+
+=head2 remove
+
+FIXME
+
+=head2 set
+
+FIXME
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Hook-Modular>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Hook-Modular/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Hook-Modular/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Hook-Modular/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHORS
 
-Tatsuhiko Miyagawa C<< <miyagawa@bulknews.net> >>
-
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
+  Tatsuhiko Miyagawa <miyagawa@bulknews.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by the authors.
+This software is copyright (c) 2007 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
