@@ -1,7 +1,10 @@
-package Hook::Modular::Crypt;
-use warnings;
+use 5.008;
 use strict;
-our $VERSION = '0.09';
+use warnings;
+
+package Hook::Modular::Crypt;
+our $VERSION = '1.100820';
+# ABSTRACT: Crypt mechanism for passwords in workflows
 use Module::Pluggable::Fast
   search  => [qw/Hook::Modular::Crypt/],
   require => 1;
@@ -25,49 +28,63 @@ sub encrypt {
     join '::', $driver, $handler->encrypt($plaintext, @param);
 }
 1;
+
+
 __END__
+=pod
 
 =head1 NAME
 
 Hook::Modular::Crypt - Crypt mechanism for passwords in workflows
 
-=head1 SYNOPSIS
+=head1 VERSION
 
-    Hook::Modular::Crypt->new;
+version 1.100820
 
-=head1 DESCRIPTION
+=head1 METHODS
 
-None yet.
+=head2 decrypt
+
+FIXME
+
+=head2 encrypt
+
+FIXME
+
+=head1 INSTALLATION
+
+See perlmodinstall for information and options on installing Perl modules.
 
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
 Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
-
-=head1 INSTALLATION
-
-See perlmodinstall for information and options on installing Perl modules.
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Hook-Modular>.
 
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
-Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Hook-Modular/>.
+Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
+site near you, or see
+L<http://search.cpan.org/dist/Hook-Modular/>.
+
+The development version lives at
+L<http://github.com/hanekomu/Hook-Modular/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
 
 =head1 AUTHORS
 
-Tatsuhiko Miyagawa C<< <miyagawa@bulknews.net> >>
-
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+  Marcel Gruenauer <marcel@cpan.org>
+  Tatsuhiko Miyagawa <miyagawa@bulknews.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2009 by the authors.
+This software is copyright (c) 2007 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
